@@ -7,5 +7,5 @@ PLUGIN.license = "MIT"
 PLUGIN.description = "Leiningen - automating Clojure projects without setting your hair on fire"
 PLUGIN.minRuntimeVersion = "0.3.0"
 PLUGIN.notes = {
-    "Requires Java to be installed"
+    "Requires Java to be installed",
 }
