@@ -8,6 +8,7 @@ pub struct BackendInstallContext {
     pub tool: String,
     pub version: String,
     pub install_path: PathBuf,
+    pub download_path: PathBuf,
 }
 
 #[derive(Debug)]
@@ -36,6 +37,10 @@ impl IntoLua for BackendInstallContext {
             "install_path",
             self.install_path.to_string_lossy().to_string(),
         )?;
+        table.set(
+            "download_path",
+            self.download_path.to_string_lossy().to_string(),
+        )?;
         Ok(Value::Table(table))
     }
 }
