@@ -5,7 +5,7 @@ use crate::cli::args::{BackendArg, ToolArg};
 use crate::config::tracking::Tracker;
 use crate::config::{Config, Settings};
 use crate::runtime_symlinks;
-use crate::toolset::{ToolVersion, Toolset, ToolsetBuilder};
+use crate::toolset::{ToolVersion, ToolsetBuilder, get_versions_needed_by_tracked_configs};
 use crate::ui::multi_progress_report::MultiProgressReport;
 use crate::ui::prompt;
 use crate::{backend::Backend, config};
@@ -89,12 +89,10 @@ pub async fn prunable_tools(
         to_delete.retain(|_, (_, tv)| tools.contains(&tv.ba()));
     }
 
-    for cf in config.get_tracked_config_files().await?.values() {
-        let mut ts = Toolset::from(cf.to_tool_request_set()?);
-        ts.resolve(config).await?;
-        for (_, tv) in ts.list_current_versions() {
-            to_delete.remove(&(tv.ba().short.to_string(), tv.tv_pathname()));
-        }
+    // Remove versions that are still needed by tracked configs
+    let needed_versions = get_versions_needed_by_tracked_configs(config).await?;
+    for key in needed_versions {
+        to_delete.remove(&key);
     }
 
     Ok(to_delete.into_values().collect())
