@@ -18,6 +18,9 @@ use std::path::PathBuf;
 ///
 /// This command uses the `watchexec` tool to watch for changes to files and rerun the specified task(s).
 /// It must be installed for this command to work, but you can install it with `mise use -g watchexec@latest`.
+///
+/// For more advanced process management (daemon management, auto-restart, readiness checks,
+/// cron scheduling), see mise's sister project: https://pitchfork.jdx.dev
 #[derive(Debug, clap::Args)]
 #[clap(visible_alias = "w", verbatim_doc_comment, after_long_help = AFTER_LONG_HELP)]
 pub struct Watch {
@@ -1174,12 +1177,13 @@ pub enum FsEvent {
 }
 
 #[derive(Clone, Copy, Debug, Eq, PartialEq, ValueEnum)]
+#[clap(rename_all = "lower")]
 pub enum ShellCompletion {
     Bash,
     Elvish,
     Fish,
     Nu,
-    Powershell,
+    PowerShell,
     Zsh,
 }
 
