@@ -348,6 +348,7 @@ pub async fn build_session(
     aliases: indexmap::IndexMap<String, String>,
     loaded_tools: IndexSet<String>,
     watch_files: BTreeSet<WatchFilePattern>,
+    config_paths: IndexSet<PathBuf>,
 ) -> Result<HookEnvSession> {
     let mut max_modtime = UNIX_EPOCH;
     for cf in get_watch_files(watch_files)? {
@@ -356,12 +357,6 @@ pub async fn build_session(
         }
     }
 
-    let config_paths = if let Ok(paths) = config.path_dirs().await {
-        paths.iter().cloned().collect()
-    } else {
-        IndexSet::new()
-    };
-
     let loaded_configs: IndexSet<PathBuf> = config.config_files.keys().cloned().collect();
 
     // Update the last full check timestamp (only if cache_ttl feature is enabled)
