@@ -429,9 +429,6 @@ impl Backend for JavaPlugin {
         ctx: &InstallContext,
         mut tv: ToolVersion,
     ) -> eyre::Result<ToolVersion> {
-        // Java installation has 3 operations: download, install (extract), verify
-        ctx.pr.start_operations(3);
-
         // Check if URL already exists in lockfile platforms first
         let platform_key = self.get_platform_key();
         let (metadata, tarball_path) =
@@ -471,7 +468,9 @@ impl Backend for JavaPlugin {
                 (metadata, tarball_path)
             };
 
+        ctx.pr.next_operation();
         self.install(&tv, ctx.pr.as_ref(), &tarball_path, metadata)?;
+        ctx.pr.next_operation();
         self.verify(&tv, ctx.pr.as_ref())?;
 
         Ok(tv)
